==> cscec5b-rmat-impl-3.0.1-20241109.065542-320-sources.jar: com/ejianc/business/rmat/controller/DailyController.java <==
package com.ejianc.business.rmat.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.rmat.bean.DailyEntity;
import com.ejianc.business.rmat.service.IDailyService;
import com.ejianc.business.rmat.vo.DailyVO;
import com.ejianc.business.rmat.vo.RentReportCalcVO;
import com.ejianc.business.rmat.vo.RentReportVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 日租金
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("daily")
public class DailyController implements Serializable {
	private static final long serialVersionUID = 1L;

    @Autowired
    private IDailyService service;

    @Autowired
    private IOrgApi orgApi;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<DailyVO> saveOrUpdate(@RequestBody DailyVO dailyVO) {
    	return CommonResponse.success("保存或修改单据成功！", service.saveOrUpdate(dailyVO));
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<DailyVO> queryDetail(Long id) {
    	DailyEntity entity = service.selectById(id);
    	DailyVO vo = BeanMapper.map(entity, DailyVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<DailyVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (DailyVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(DailyVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<DailyVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("realCorpName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        boolean mobile = param.getParams().containsKey("projectId");
        if(!mobile){
            if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
                param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));
            } else {
                param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgApi.findChildrenByParentIdWithoutProjectDept(
                            InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
            }
        }

        IPage<DailyEntity> page = service.queryPage(param,false);
        IPage<DailyVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), DailyVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("realCorpName");
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        boolean mobile = param.getParams().containsKey("projectId");
        if(!mobile){
            if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
                param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));
            } else {
                param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgApi.findChildrenByParentIdWithoutProjectDept(
                        InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
            }
        }
        List<DailyEntity> list = service.queryList(param);
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Daily-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refDailyData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<DailyVO>> refDailyData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<DailyEntity> page = service.queryPage(param,false);
        IPage<DailyVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), DailyVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    @RequestMapping(path = "/generation", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> generation(HttpServletRequest request) {
        return service.generation(request);
    }


    /**
     * @Description queryReport 查询数据
     * @param projectId
     */
    @RequestMapping(value = "/qryReport", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<RentReportVO> qryReport(@RequestParam(value = "projectId") Long projectId, @RequestParam(value = "beginDate") String beginDate,
                                                    @RequestParam(value = "endDate") String endDate) {
        return CommonResponse.success("查询数据成功！", service.qryReport(projectId, beginDate, endDate));
    }

    /**
     * @Description queryReportCalcList 查询计算过程数据
     * @param projectId
     */
    @RequestMapping(value = "/qryReportCalcList", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<RentReportCalcVO>> qryReportCalcList(@RequestParam(value = "projectId") Long projectId, @RequestParam(value = "beginDate") String beginDate,
                                                                      @RequestParam(value = "endDate") String endDate, @RequestParam(value = "materialId", required = false) Long materialId) {
        return CommonResponse.success("查询数据成功！", service.qryReportCalcList(projectId, beginDate, endDate, materialId));
    }

    @RequestMapping(value = "/copyToDate", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> copyToDate(String fromDate, String newDate) {
        return CommonResponse.success("复制数据成功！", service.copyToDate(fromDate, newDate));
    }
}

==> cscec5b-rmat-impl-3.0.1-20250120.095631-338-sources.jar: com/ejianc/business/rmat/controller/DailyController.java <==
package com.ejianc.business.rmat.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.rmat.bean.DailyEntity;
import com.ejianc.business.rmat.service.IDailyService;
import com.ejianc.business.rmat.vo.DailyVO;
import com.ejianc.business.rmat.vo.RentReportCalcVO;
import com.ejianc.business.rmat.vo.RentReportVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 日租金
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("daily")
public class DailyController implements Serializable {
	private static final long serialVersionUID = 1L;

    @Autowired
    private IDailyService service;

    @Autowired
    private IOrgApi orgApi;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<DailyVO> saveOrUpdate(@RequestBody DailyVO dailyVO) {
    	return CommonResponse.success("保存或修改单据成功！", service.saveOrUpdate(dailyVO));
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<DailyVO> queryDetail(Long id) {
    	DailyEntity entity = service.selectById(id);
    	DailyVO vo = BeanMapper.map(entity, DailyVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<DailyVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (DailyVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(DailyVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<DailyVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("realCorpName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        boolean mobile = param.getParams().containsKey("projectId");
        if(!mobile){
            if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
                param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));
            } else {
                param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgApi.findChildrenByParentIdWithoutProjectDept(
                            InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
            }
        }

        IPage<DailyEntity> page = service.queryPage(param,false);
        IPage<DailyVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), DailyVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        fuzzyFields.add("realCorpName");
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        boolean mobile = param.getParams().containsKey("projectId");
        if(!mobile){
            if(OrgVO.ORG_TYPE_DEPARTMENT.toString().equals(InvocationInfoProxy.getOrgType())){
                param.getParams().put("orgId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getOrgId()));
            } else {
                param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, orgApi.findChildrenByParentIdWithoutProjectDept(
                        InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
            }
        }
        List<DailyEntity> list = service.queryList(param);
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Daily-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refDailyData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<DailyVO>> refDailyData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<DailyEntity> page = service.queryPage(param,false);
        IPage<DailyVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), DailyVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    @RequestMapping(path = "/generation", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> generation(HttpServletRequest request) {
        return service.generation(request);
    }


    /**
     * @Description queryReport 查询数据
     * @param projectId
     */
    @RequestMapping(value = "/qryReport", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<RentReportVO> qryReport(@RequestParam(value = "projectId") Long projectId, @RequestParam(value = "beginDate") String beginDate,
                                                    @RequestParam(value = "endDate") String endDate) {
        return CommonResponse.success("查询数据成功！", service.qryReport(projectId, beginDate, endDate));
    }

    /**
     * @Description queryReportCalcList 查询计算过程数据
     * @param projectId
     */
    @RequestMapping(value = "/qryReportCalcList", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<RentReportCalcVO>> qryReportCalcList(@RequestParam(value = "projectId") Long projectId, @RequestParam(value = "beginDate") String beginDate,
                                                                      @RequestParam(value = "endDate") String endDate, @RequestParam(value = "materialId", required = false) Long materialId) {
        return CommonResponse.success("查询数据成功！", service.qryReportCalcList(projectId, beginDate, endDate, materialId));
    }

    @RequestMapping(value = "/copyToDate", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> copyToDate(String fromDate, String newDate) {
        return CommonResponse.success("复制数据成功！", service.copyToDate(fromDate, newDate));
    }

    /**
     * @Description qryReportNew 查询数据
     * @param projectId
     */
    @RequestMapping(value = "/qryReportNew", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<RentReportVO> qryReportNew(@RequestParam(value = "projectId") Long projectId, @RequestParam(value = "beginDate") String beginDate,
                                                  @RequestParam(value = "endDate") String endDate) {
        return CommonResponse.success("查询数据成功！", service.qryReportNew(projectId, beginDate, endDate));
    }
}
